@@ -22,7 +22,6 @@
     ObjectSetPrototypeOf,
     Symbol,
     SymbolFor,
-    SymbolToStringTag,
     TypeError,
     WeakSet,
     WeakSetPrototypeAdd,
@@ -59,10 +58,6 @@
         inspect({ port1: this.port1, port2: this.port2 })
       }`;
     }
-
-    get [SymbolToStringTag]() {
-      return "MessageChannel";
-    }
   }
 
   webidl.configurePrototype(MessageChannel);
@@ -174,10 +169,6 @@
         this[_id] = null;
       }
     }
-
-    get [SymbolToStringTag]() {
-      return "MessagePort";
-    }
   }
 
   defineEventHandler(MessagePort.prototype, "message", function (self) {
